# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2016-2023
#

input secondarySymbol = "/CL";
input length = 20;

def secClose = close(secondarySymbol);
def divergence = reference BBDivergence(length = length, "secondary symbol" = secondarySymbol);
def macd = reference MACD("fast length" = 12, "slow length" = 26);
def stochastic = reference StochasticFull("k period" = 30, "slowing period" = 3);
def roc = reference RateOfChange(price = secClose, length = 3);

AddOrder(OrderType.BUY_TO_OPEN,
    Highest(divergence, 3) > 20 and divergence < divergence[1] and
    close > close[2] and Average(secClose, 40) > Average(secClose, 40)[2] and
    Correlation(close, secClose, 20) > -0.4,
    tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "BBDivergenceLE");

AddOrder(OrderType.SELL_TO_CLOSE,
    (macd crosses below ExpAverage(macd, 9) and stochastic > 85) or
    (Lowest(divergence, 3) < -20 and roc < -3) or
    (close < Lowest(low, 15)[1] and Correlation(close, secClose, 60) < -0.4),
    tickcolor = GetColor(4), arrowcolor = GetColor(4), name = "BBDivergenceLX");

AddOrder(OrderType.SELL_TO_OPEN,
    Lowest(divergence, 3) < -20 and divergence > divergence[1] and
    close < close[2] and Average(secClose, 40) < Average(secClose, 40)[2] and
    Correlation(close, secClose, 20) > -0.4,
    tickcolor = GetColor(5), arrowcolor = GetColor(5), name = "BBDivergenceSE");

AddOrder(OrderType.BUY_TO_CLOSE,
    (macd crosses above ExpAverage(macd, 9) and stochastic < 25 and secClose >= 1.04 * Lowest(secClose, 4)) or
    (Highest(divergence, 3) > 20 and roc > 4.5) or
    (close > Highest(high, 15)[1] and Correlation(close, secClose, 60) < -0.4),
    tickcolor = GetColor(6), arrowcolor = GetColor(6), name = "BBDivergenceSX");
