# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2018-2023
#

declare hide_on_daily;

input nightSessionFromMidnight = 0100;
input firstHourTrading = 0930;
input mainSession = 1030;
input noMoreLongPositions = 1545;
input nightSessionFromMainSessionEnd = 1615;
input useFilter = yes;

def isNightSessionFromMidnight = SecondsFromTime(nightSessionFromMidnight) >= 0 and SecondsTillTime(firstHourTrading) > 0;
def isFirstHourTrading = SecondsFromTime(firstHourTrading) >= 0 and SecondsTillTime(mainSession) > 0;
def isMainSession = SecondsFromTime(mainSession) >= 0 and SecondsTillTime(nightSessionFromMainSessionEnd) > 0;

def newFirstHourTrading = isFirstHourTrading and !isFirstHourTrading[1];
def firstHourHigh = if newFirstHourTrading then high else if isFirstHourTrading then Max(high, firstHourHigh[1]) else firstHourHigh[1];
def firstHourLow = if newFirstHourTrading then low else if isFirstHourTrading then Min(low, firstHourLow[1]) else firstHourLow[1];

def newNightSessionFromMidnight = isNightSessionFromMidnight and !isNightSessionFromMidnight[1];
def cOvernightVolume = if newNightSessionFromMidnight then volume else if isNightSessionFromMidnight then cOvernightVolume[1] + volume else cOvernightVolume[1];

def count = count[1] + if newNightSessionFromMidnight then 1 else 0;

def overnightVolume1;
def overnightVolume2;
def overnightVolume3;
def overnightVolume4;
def overnightVolume5;
if (newNightSessionFromMidnight and count > 1) {
    overnightVolume1 = cOvernightVolume[1];
    overnightVolume2 = overnightVolume1[1];
    overnightVolume3 = overnightVolume2[1];
    overnightVolume4 = overnightVolume3[1];
    overnightVolume5 = overnightVolume4[1];
} else {
    overnightVolume1 = overnightVolume1[1];
    overnightVolume2 = overnightVolume2[1];
    overnightVolume3 = overnightVolume3[1];
    overnightVolume4 = overnightVolume4[1];
    overnightVolume5 = overnightVolume5[1];
}

def averageOvernightVolume = if count > 5 then (overnightVolume1 + overnightVolume2 + overnightVolume3 + overnightVolume4 + overnightVolume5) / 5 else Double.NaN;
def filter = cOvernightVolume > averageOvernightVolume;

AddOrder(OrderType.BUY_TO_OPEN, (if useFilter then filter else yes) and isMainSession and SecondsTillTime(noMoreLongPositions) > 0 and high > firstHourHigh, tickcolor = GetColor(0), arrowcolor = GetColor(0), name = "FirstHourBreakoutLE");
AddOrder(OrderType.SELL_TO_OPEN, (if useFilter then filter else yes) and isMainSession and SecondsTillTime(noMoreLongPositions) > 0 and low < firstHourLow, tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "FirstHourBreakoutSE");
AddOrder(OrderType.BUY_TO_CLOSE, SecondsFromTime(nightSessionFromMainSessionEnd) > 0, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "FirstHourBreakoutSX");
AddOrder(OrderType.SELL_TO_CLOSE, SecondsFromTime(nightSessionFromMainSessionEnd) > 0, tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "FirstHourBreakoutLX");
