# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2022-2023
#

input atrLength = 15;
input vfiLength = 130;
input atrPctChg = 90;
input vixPctChg = 60;
input vfiThreshold = -20;

def atr = Average (TrueRange(high, close, low), atrLength);
def atrPctChgUp = (atr / Lowest(atr, 25)[1] - 1) * 100;
def vix = close("VIX");
def vixPctChgUp = (vix / Lowest(vix, 25)[1] - 1) * 100;
def vfi = reference VolumeFlowIndicator(length = vfiLength);
def vfiAvg = Average(vfi, 10);
def month = GetMonth();

AddOrder(OrderType.BUY_TO_OPEN, (month[-1] >= 10 or month[-1] < 8) and
     (vixPctChgUp < vixPctChg or
     atrPctChgUp < atrPctChg) and
     vfi > vfiThreshold,
    tickcolor = GetColor(0),
    arrowcolor = GetColor(0),
    name = "HSS_LE");
AddOrder(OrderType.SELL_TO_CLOSE, month[-1] == 8,
    tickcolor = GetColor(1),
    arrowcolor = GetColor(1),
    name = "HSS_Seasonal_LX");
AddOrder(OrderType.SELL_TO_CLOSE, vixPctChgUp > 2 * vixPctChg,
    tickcolor = GetColor(2),
    arrowcolor = GetColor(2),
    name = "HSS_VIX_LX");
AddOrder(OrderType.SELL_TO_CLOSE, vfi crosses below vfiThreshold
    and vfiAvg < vfiAvg[1],
    tickcolor = GetColor(3),
    arrowcolor = GetColor(3),
    name = "HSS_VFI_LX");
