# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2014-2023
#

input maxFlagLength = 15;
input maxFlagHeight = 2.5;
input maxPoleLength = 23;
input minPoleHeight = 5.5;
input upTrendLength = 70;
input minLengthBetweenFlags = 50;
input minAtrPercentChange = 5.0;
input strictBreakout = yes;
input profitTargetConstant = 1.2;
input stopLossDelayLength = 5;
input stopAtr = 3.0;
input trailStopLength = 5;
input trailStopAtr = 3.0;
input inactivityExitLength = 70;
input inactivityAtr = 4.0;
input timeExitLength = 100;

Assert(maxFlagLength > 0, "'maxFlagLength' must be positive: " + maxFlagLength);
Assert(maxPoleLength > 0, "'maxPoleLength' must be positive: " + maxPoleLength);
Assert(stopLossDelayLength > 0, "'stopLossDelayLength' must be positive: " + stopLossDelayLength);
Assert(inactivityExitLength > 0, "'inactivityExitLength' must be positive: " + inactivityExitLength);
Assert(timeExitLength > 0, "'timeExitLength' must be positive: " + timeExitLength);

def atr = Average(TrueRange(high,  close,  low),  40);

def isFlag = reference IntradayFlagFormation(maxFlagLength = maxFlagLength, maxFlagHeight = maxFlagHeight, maxPoleLength = maxPoleLength, minPoleHeight = minPoleHeight, upTrendLength = upTrendLength, minAtrPercentChange = minAtrPercentChange).Flag;
def pole = reference IntradayFlagFormation(maxFlagLength = maxFlagLength, maxFlagHeight = maxFlagHeight, maxPoleLength = maxPoleLength, minPoleHeight = minPoleHeight, upTrendLength = upTrendLength, minAtrPercentChange = minAtrPercentChange).pole;
def lf = reference IntradayFlagFormation(maxFlagLength = maxFlagLength, maxFlagHeight = maxFlagHeight, maxPoleLength = maxPoleLength, minPoleHeight = minPoleHeight, upTrendLength = upTrendLength, minAtrPercentChange = minAtrPercentChange).lf;

def flagSum = Sum(isFlag, minLengthBetweenFlags) == 1;

def poleSave;
def lfSave;
if isFlag and flagSum {
    poleSave = pole;
    lfSave = lf;
} else {
    poleSave = poleSave[1];
    lfSave = lfSave[1];
}

AddOrder(OrderType.BUY_TO_OPEN, isFlag and flagSum, tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "FlagLE");

def entryPrice = EntryPrice();
def afterEntryCount = if IsNaN(entryPrice[1]) and !IsNaN(entryPrice) then 1 else if !IsNaN(entryPrice) then afterEntryCount[1] + 1 else Double.NaN;

AddOrder(OrderType.SELL_TO_CLOSE, close >= entryPrice + profitTargetConstant * poleSave, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "FlagProfitTargetLX");
AddOrder(OrderType.SELL_TO_CLOSE, afterEntryCount > stopLossDelayLength and close < lfSave - stopAtr * atr, tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "FlagStopLX");
AddOrder(OrderType.SELL_TO_CLOSE, close < Highest(close, trailStopLength) - trailStopAtr * atr, tickcolor = GetColor(4), arrowcolor = GetColor(4), name = "FlagTrailStopLX");
AddOrder(OrderType.SELL_TO_CLOSE, afterEntryCount > inactivityExitLength and close < entryPrice + inactivityAtr * atr, tickcolor = GetColor(5), arrowcolor = GetColor(5), name = "FlagInactivityLX");
AddOrder(OrderType.SELL_TO_CLOSE, afterEntryCount > timeExitLength, tickcolor = GetColor(6), arrowcolor = GetColor(6), name = "FlagTimeLX");
