# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2014-2023
#

input fastLength = 6;
input slowLength = 200;
input averageType = AverageType.EXPONENTIAL;
input rsiLength = 2;
input rsiOverSoldLevel = 5;
input rsiOverBoughtLevel = 95;
input rsiAverageType = AverageType.WILDERS;
input highLength = 2;

plot FastMA = MovingAverage(averageType, close, fastLength);
plot SlowMA = MovingAverage(averageType, close, slowLength);

def rsi = reference RSI(length = rsiLength, averageType = rsiAverageType);

def entryPrice = EntryPrice();
def rsiSetup = if IsNaN(entryPrice) and rsi < rsiOverSoldLevel then yes else if !IsNaN(entryPrice) or rsi > rsiOverBoughtLevel then no else rsiSetup[1];
def reversalSetup = close > Highest(high, highLength)[1];

AddOrder(OrderType.BUY_TO_OPEN, close > SlowMA and rsiSetup and reversalSetup, tickcolor = GetColor(0), arrowcolor = GetColor(0), name = "LongHaulLE");
AddOrder(OrderType.SELL_TO_CLOSE, !IsNaN(entryPrice) and close crosses below FastMA, tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "LongHaulCrossLX");
AddOrder(OrderType.SELL_TO_CLOSE, !IsNaN(entryPrice) and low <= Lowest(low, 3)[1], tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "LongHaulStopLX");
