# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2021-2023
#

input atrLength = 2;
input stochLength1 = 14;
input stochLength2 = 40;
input atrPctChgBuy = 60;
input atrPctChgSell = 100;
input vixPctChgBuy = 30;
input vixPctChgSell = 200;
input pricePctChg = 6;
input stochOversold = 25;
input stochOverbought = 85;

def atr = Average(TrueRange(high, close, low), atrLength);
def vix = close("VIX");
def stoch1 = reference StochasticFull("k period" = stochLength1);
def stoch2 = reference StochasticFull("k period" = stochLength2);

def atrPctChgDown = (atr / Highest(atr, 15)[1] - 1) * 100;
def atrPctChgUp = (atr / Lowest(atr, 15)[1] - 1) * 100;
def vixPctChgDown = (vix / Highest(vix, 15)[1] - 1) * 100;
def vixPctChgUp = (vix / Lowest(vix, 15)[1] - 1) * 100;
def pricePctChgUp = (Highest(close, 2) / Lowest(close, 4) - 1) * 100;
def pricePctChgDown = (Lowest(close, 2) / Highest(close, 4) - 1) * 100;

AddOrder(OrderType.BUY_TO_OPEN, (atrPctChgDown < atrPctChgBuy or vixPctChgDown < vixPctChgBuy) and
    pricePctChgUp > pricePctChg and
    Lowest(stoch1, 4) < stochOversold and
    Lowest(stoch2, 4) < stochOversold and
    stoch1 >= stoch2 and
    (Lowest(close, 10) / Highest(close, 100) - 1) * 100 < -15,
    tickcolor = GetColor(0),
    arrowcolor = GetColor(0),
    name = "MBMA_LE");

AddOrder(OrderType.SELL_TO_CLOSE, (atrPctChgUp > atrPctChgSell or vixPctChgUp > vixPctChgSell) and
    pricePctChgDown < -pricePctChg and
    Highest(stoch1, 4) > stochOverbought and
    Highest(stoch2, 4) > stochOverbought and
    stoch2 >= stoch1 and
    close < Average(close, 20) and
    (volume / Average(volume, 50)[1] - 1) * 100 > 80,
    tickcolor = GetColor(1),
    arrowcolor = GetColor(1),
    name = "MBMA_LX");
