# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2017-2023
#

input minLength = 20;
input maxLength = 400;
input minRangeForUptrend = 5.0;
input minUpMove = 0.5;
input tolerance = 1.0;

def lowestLowOffset = GetMinValueOffset(low, maxLength);
def highestHighOffset = GetMaxValueOffset(high, maxLength);

def lowestLow = GetValue(low, lowestLowOffset, maxLength);
def highestHigh = GetValue(high, highestHighOffset, maxLength);
def lowestLowAfterHighestHigh;
if IsNaN(highestHighOffset) {
    lowestLowAfterHighestHigh = Double.NaN;
} else {
    lowestLowAfterHighestHigh = fold i = 0 to Max(0, highestHighOffset) with m = Double.POSITIVE_INFINITY do Min(m, GetValue(low, i, maxLength));
}

def move1x = lowestLowOffset - highestHighOffset;
def move1y = highestHigh - lowestLow;
def move2x = highestHighOffset;
def move2y = highestHigh - lowestLowAfterHighestHigh;
def move3y = close - lowestLowAfterHighestHigh;

def buy = lowestLowOffset > highestHighOffset and
    move1x > minLength and
    move2x > minLength and
    move1y >= minRangeForUptrend and
    move2y >= move1y * (50 - tolerance) / 100 and
    move2y <= move1y * (50 + tolerance) / 100 and
    move3y >= minUpMove;

def buyUnique = buy and Sum(buy[1], minLength * 2) == 0;

AddOrder(OrderType.BUY_AUTO, buyUnique, tickcolor = GetColor(1), arrowcolor = GetColor(1));
