# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2017-2023
#

input secondSymbol = "";
input fastLength = 4;
input slowLength = 40;
input mode = {"Trend Following", "Mean Reversion", default "Trend & PullBack"};

Assert(secondSymbol != "", "'second symbol' cannot be empty");

def ratio = close / close(secondSymbol);
def fastAvg = Average(ratio, fastLength);
def slowAvg = Average(ratio, slowLength);

def buy;
def sell;
switch (mode) {
case "Trend Following":
    buy = fastAvg crosses above slowAvg;
    sell = fastAvg crosses below slowAvg;
case "Mean Reversion":
    buy = ratio crosses below fastAvg;
    sell = ratio crosses above fastAvg;
case "Trend & PullBack":
    buy = fastAvg > slowAvg and ratio crosses below fastAvg;
    sell = fastAvg < slowAvg and ratio crosses above fastAvg;
}

AddOrder(OrderType.BUY_TO_OPEN, buy, tickcolor = GetColor(0), arrowcolor = GetColor(0), name = "PairTradingLong_LE");
AddOrder(OrderType.SELL_TO_CLOSE, sell, tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "PairTradingLong_LX");

