# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2017-2023
#

input firstSymbol = "";
input fastLength = 4;
input slowLength = 40;
input mode = {"Trend Following", "Mean Reversion", default "Trend & PullBack"};

Assert(firstSymbol != "", "'first symbol' cannot be empty");

def ratio = close(firstSymbol) / close;
def fastAvg = Average(ratio, fastLength);
def slowAvg = Average(ratio, slowLength);

def buy;
def sell;
switch (mode) {
case "Trend Following":
    sell = fastAvg crosses above slowAvg;
    buy = fastAvg crosses below slowAvg;
case "Mean Reversion":
    sell = ratio crosses below fastAvg;
    buy = ratio crosses above fastAvg;
case "Trend & PullBack":
    sell = fastAvg > slowAvg and ratio crosses below fastAvg;
    buy = fastAvg < slowAvg and ratio crosses above fastAvg;
}

AddOrder(OrderType.SELL_TO_OPEN, sell, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "PairTradingShort_SE");
AddOrder(OrderType.BUY_TO_CLOSE, buy, tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "PairTradingShort_SX");
