# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2016-2023
#

input length = 18;
input rAverageLength = 3;
input lag = 10;
input averageLength = 50;
input trendLevel = 0.42;
input maxLevel = 0.85;
input lrCritLevel = 10;
input averageType = AverageType.SIMPLE;

def ma = MovingAverage(averageType, close, averageLength);
def r2 = reference RSquared(length = length, "r average length" = rAverageLength);
def lr = reference LinearRegressionSlope(price = close, length = length) * 100;

AddOrder(OrderType.BUY_TO_OPEN, r2 crosses above trendLevel and
    r2 < maxLevel and
    r2 > r2[lag] and
    close > ma and
    lr > lrCritLevel, tickcolor = GetColor(0), arrowcolor = GetColor(0), name = "R2_StrongUptrendLE");
AddOrder(OrderType.SELL_TO_OPEN, r2 crosses above trendLevel and
    r2 < maxLevel and
    r2 > r2[lag] and
    close < ma and
    lr < -lrCritLevel, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "R2_StrongDowntrendSE");

AddOrder(OrderType.SELL_TO_CLOSE, close crosses below ma, tickcolor = GetColor(4), arrowcolor = GetColor(4), name = "MovAvgLX");
AddOrder(OrderType.BUY_TO_CLOSE, close crosses above ma, tickcolor = GetColor(5), arrowcolor = GetColor(5), name = "MovAvgSX");
