# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2021-2023
#
input price = close;
input rocLength = 12;
input averageLength = 3;
input rmsLength = 12;
input emaLength = 200;
input numRmss = 1.0;
input averageType = AverageType.EXPONENTIAL;

plot EMA = ExpAverage(price, emaLength);
def uptrend = price > EMA;
def ROCAvg = reference RateOfChangeWithBands(price = price, "roc length" = rocLength, "average length" = averageLength, "rms length" = rmsLength, "average type" = averageType);
def rms = reference RateOfChangeWithBands(price = price, "roc length" = rocLength, "average length" = averageLength, "rms length" = rmsLength, "average type" = averageType)."+RMS";
def lowerBand = -numRmss * rms;
def upperBand = numRmss * rms;

AddOrder(OrderType.BUY_TO_OPEN, uptrend and
    ROCAvg crosses above lowerBand, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "ROCWB_LE");
AddOrder(OrderType.SELL_TO_CLOSE, uptrend and
    ROCAvg crosses below upperBand, tickcolor = GetColor(4), arrowcolor = GetColor(4), name = "ROCWB_LX");
AddOrder(OrderType.SELL_TO_CLOSE, price crosses below EMA, tickcolor = GetColor(7), arrowcolor = GetColor(7), name = "EMA_LX");
AddOrder(OrderType.SELL_TO_OPEN, !uptrend and
    ROCAvg crosses below upperBand, tickcolor = GetColor(5), arrowcolor = GetColor(5), name = "ROCWB_SE");
AddOrder(OrderType.BUY_TO_CLOSE, !uptrend and
    ROCAvg crosses above lowerBand, tickcolor = GetColor(6), arrowcolor = GetColor(6), name = "ROCWB_SX");
AddOrder(OrderType.BUY_TO_CLOSE, price crosses above EMA, tickcolor = GetColor(8), arrowcolor = GetColor(8), name = "EMA_SX");

EMA.SetDefaultColor(GetColor(1));
