# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2017-2023
#

input symbol2 = "FXY";
input symbol3 = "SPY";
input length = 25;
input rocLength = 3;
input divergenceLength = 50;
input divergenceMomentumLength = 50;
input exitLength = 11;
input lag = 3;
input divergenceCriticalLevel = 75;
input corr3level = 0.8;

def divergenceCriticalLevelShort = 100 - divergenceCriticalLevel;
def ma = Average(close, length);
def lr = reference LinearRegressionSlope(price = close, length = length);
def rd = reference RegressionDivergence(secondarySymbol = symbol2, rocLength = rocLength, divergenceLength = divergenceLength, divergenceMomentumLength = divergenceMomentumLength);

def roc1 = reference RateOfChange(price = close, length = rocLength);
def roc3 = reference RateOfChange(price = close(symbol3), length = rocLength);
def corr3 = Correlation(roc1, roc3, divergenceLength);

def entryPrice = EntryPrice();
def afterEntryCount = if IsNaN(entryPrice[1]) and !IsNaN(entryPrice) then 1 else if !IsNaN(entryPrice) then afterEntryCount[1] + 1 else Double.NaN;

AddOrder(OrderType.BUY_TO_OPEN,
    rd[lag] > divergenceCriticalLevel and
    rd < rd[lag] and
    rd > divergenceCriticalLevelShort and
    corr3 < corr3level and
    (lr >= lr[1] or close > ma),
    price = close,
    tickcolor = GetColor(1),
    arrowcolor = GetColor(1),
    name = "RegressionDivergenceStratLE");
AddOrder(OrderType.SELL_TO_OPEN,
    rd[lag] < divergenceCriticalLevelShort and
    rd > rd[lag] and
    rd < divergenceCriticalLevel and
    corr3 < corr3level and
    (lr <= lr[1] or close < ma),
    price = close,
    tickcolor = GetColor(1),
    arrowcolor = GetColor(1),
    name = "RegressionDivergenceStratSE");
AddOrder(OrderType.SELL_TO_CLOSE, afterEntryCount > exitLength, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "RegressionDivergenceStratLX");
AddOrder(OrderType.BUY_TO_CLOSE, afterEntryCount > exitLength, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "RegressionDivergenceStratSX");
