# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2013-2023
#

input typicalLength = 5;
input haLength = 8;
input paintBars = yes;

def haOpen = (ohlc4[1] + haOpen[1]) / 2;
def haClose = (ohlc4 + haOpen + Max(high, haOpen) + Min(low, haOpen)) / 4;

plot AvgTyp = ExpAverage(hlc3, typicalLength);
plot AvgHAC = ExpAverage(haClose, haLength);

def buy = AvgTyp > AvgHAC and close > open;
def sell = AvgTyp < AvgHAC and close < open;
def state = {default undefined, uptrend, downtrend};
state = if IsNaN(buy) or IsNaN(sell) then state[1]
    else if buy then state.uptrend
    else if sell then state.downtrend
    else state[1];

AvgTyp.SetDefaultColor(GetColor(1));
AvgHAC.SetDefaultColor(GetColor(2));
DefineGlobalColor("Uptrend", Color.GREEN);
DefineGlobalColor("Downtrend", Color.GRAY);
DefineGlobalColor("Undefined", Color.YELLOW);

AssignPriceColor(if !paintBars then Color.CURRENT
    else if state == state.uptrend then GlobalColor("Uptrend")
    else if state == state.downtrend then GlobalColor("Downtrend")
    else GlobalColor("Undefined"));

AddOrder(OrderType.BUY_AUTO, buy, tickColor = GetColor(1), arrowColor = GetColor(1), name = "SVEHaTypCross_LE");
AddOrder(OrderType.SELL_AUTO, sell, tickColor = GetColor(2), arrowColor = GetColor(2), name = "SVEHaTypCross_SE");
