# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2014-2023
#

input length = 8;
input exitLength = 21;

def haClose = CompoundValue(1, ohlc4, close);
def haOpen = CompoundValue(1, (haOpen[1] + haClose[1]) / 2, open);
def haHigh = CompoundValue(1, Max(high, Max(haOpen, haClose)), high);
def haLow = CompoundValue(1, Min(low, Min(haOpen, haClose)), low);

plot AveragePrice = Average(hlc3, length);
plot AverageHaPrice = Average((haHigh + haLow + haOpen + haClose) / 4, length);
plot AverageExit = Average(close, exitLength);

AveragePrice.SetDefaultColor(GetColor(1));
AverageHaPrice.SetDefaultColor(GetColor(2));
AverageExit.DefineColor("Above", GetColor(3));
AverageExit.DefineColor("Below", GetColor(4));
AverageExit.AssignValueColor(if close >= AverageExit then AverageExit.Color("Above") else AverageExit.Color("Below"));

def smaTypSmaHaSign = Sign(AveragePrice - AverageHaPrice);
def basicConditionSign = if smaTypSmaHaSign == Sign(close - open) then smaTypSmaHaSign else basicConditionSign[1];
def closeSmaSign = Sign(close - Average(close, exitLength));
def combinedConditionSign = if basicConditionSign == closeSmaSign then basicConditionSign else 0;
def lastCombinedConditionSign = if combinedConditionSign != 0 then combinedConditionSign else lastCombinedConditionSign[1];

plot Market = 0.999 * LowestAll(low);
Market.DefineColor("Long", Color.UPTICK);
Market.DefineColor("Short", Color.DOWNTICK);
Market.DefineColor("Undefined", Color.GRAY);
Market.SetPaintingStrategy(PaintingStrategy.SQUARED_HISTOGRAM);
Market.AssignValueColor(if combinedConditionSign == 1 then Market.Color("Long") else if combinedConditionSign == -1 then Market.Color("Short") else Market.Color("Undefined"));

AddOrder(OrderType.BUY_AUTO, combinedConditionSign == 1 and combinedConditionSign[1] != 1 and lastCombinedConditionSign[1] != 1, tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "SVESCBasicLE");
AddOrder(OrderType.SELL_AUTO, combinedConditionSign == -1 and combinedConditionSign[1] != -1 and lastCombinedConditionSign[1] != -1, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "SVESCBasicSE");
AddOrder(OrderType.SELL_TO_CLOSE, basicConditionSign == 1 and closeSmaSign == -1, tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "SVESCEarlyLX");
AddOrder(OrderType.BUY_TO_CLOSE, basicConditionSign == -1 and closeSmaSign == 1, tickcolor = GetColor(4), arrowcolor = GetColor(4), name = "SVESCEarlySX");
