# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2019-2023
#

input years = 4;
input highFrequency = 75;
input lowFrequency = 25;

Assert(GetAggregationPeriod() == AggregationPeriod.MONTH, "The `SeasonalTrading` strategy is designed for monthly charts only");

def year = GetYear();
def month = GetMonth();
def isNewYear = year != year[1];
def positiveReturnsFrequency = reference MonthlySeasonality(years = years);
def highestFrequencyMonth = if isNewYear then 12 - GetMaxValueOffset(positiveReturnsFrequency, 12)[-11] else highestFrequencyMonth[1];
def lowestFrequencyMonth = if isNewYear then 12 - GetMinValueOffset(positiveReturnsFrequency, 12)[-11] else lowestFrequencyMonth[1];

def hasBuyCondition = if isNewYear then GetValue(positiveReturnsFrequency, GetMinValueOffset(positiveReturnsFrequency[1], 12) + 1, 13) <= lowFrequency else hasBuyCondition[1];
def hasSellCondition = if isNewYear then GetValue(positiveReturnsFrequency, GetMaxValueOffset(positiveReturnsFrequency[1], 12) + 1, 13) >= highFrequency else hasSellCondition[1];
def hasSeasonalFactor = hasBuyCondition and hasSellCondition;

AddOrder(OrderType.SELL_TO_OPEN, hasSeasonalFactor and month == highestFrequencyMonth[12], tickcolor = GetColor(0), arrowcolor = GetColor(0), name = "SeasonalTradingSE");
AddOrder(OrderType.BUY_TO_CLOSE, hasSeasonalFactor and month == lowestFrequencyMonth[12], tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "SeasonalTradingSX");
AddOrder(OrderType.BUY_TO_OPEN, hasSeasonalFactor and month == lowestFrequencyMonth[12], tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "SeasonalTradingLE");
AddOrder(OrderType.SELL_TO_CLOSE, hasSeasonalFactor and month == highestFrequencyMonth[12], tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "SeasonalTradingLX");
