# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2019-2023
#

input price  = close;
input length = 10;
input fastLengthFactor = 1.0;
input slowLengthFactor = 10.0;
input zScoreEntryLevel = 1.0;
input zScoreExitLevel = 0.5;

Assert(zScoreEntryLevel > 0, "'z score entry level' must be positive: " + zScoreEntryLevel);
Assert(zScoreExitLevel >= 0, "'z score exit level' must not be negative: " + zScoreExitLevel);

def zScore = (price - Average(price, length)) / StDev(price, length);

plot FastMA = Average(price, length * fastLengthFactor);
plot SlowMA = Average(price, length * slowLengthFactor);

AddOrder(OrderType.SELL_TO_OPEN, zScore crosses above zScoreEntryLevel and FastMA < SlowMA, tickcolor = GetColor(5), arrowcolor = GetColor(5), name = "SimpleMeanReversionSE");
AddOrder(OrderType.BUY_TO_CLOSE, zScore crosses below zScoreExitLevel, tickcolor = GetColor(3), arrowcolor = GetColor(3), name = "SimpleMeanReversionSX");
AddOrder(OrderType.BUY_TO_OPEN, zScore crosses below -zScoreEntryLevel and FastMA > SlowMA, tickcolor =GetColor(6), arrowcolor = GetColor(6), name = "SimpleMeanReversionLE");
AddOrder(OrderType.SELL_TO_CLOSE, zScore crosses above -zScoreExitLevel, tickcolor = GetColor(7), arrowcolor = GetColor(7), name = "SimpleMeanReversionLX");

FastMA.SetDefaultColor(GetColor(1));
SlowMA.SetDefaultColor(GetColor(2));
