# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2013-2023
#

input index = "SPY";
input length = 50;
input investment = 5000;
input entryLevel = 10;
input exitLevel = 50;
input stopLoss = 10.0;
input minPrice = 3.0;
input minPriceLength = 5;
input hedgeLength = 60;
input hedgeRatio = 0.5;

def minPriceOk = Lowest(close, minPriceLength) > minPrice;
def stress = reference StressIndicator(index = index, length = length).Stress;
def entryPrice = EntryPrice();
def crisisStop = close / entryPrice - 1 < -stopLoss / 100;
def isReady = if !isReady[1] and stress > 50 then yes else if IsNaN(crisisStop) then isReady[1] else if !IsNaN(entryPrice) and crisisStop then no else isReady[1];

AddOrder(OrderType.BUY_TO_OPEN, isReady and stress <= entryLevel and minPriceOk, tradeSize = investment / close, tickcolor = GetColor(1), arrowcolor = GetColor(1), name = "StressLE");

AddOrder(OrderType.SELL_TO_CLOSE, !minPriceOk, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "StressMinPriceLX");
AddOrder(OrderType.SELL_TO_CLOSE, stress >= exitLevel, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "StressLX");
AddOrder(OrderType.SELL_TO_CLOSE, crisisStop, tickcolor = GetColor(2), arrowcolor = GetColor(2), name = "StressCrisisStopLX");

def stockChange = close / close[1] - 1;
def indexChange = close(index) / close(index)[1] - 1;
def indexTrend = Average(close(index), hedgeLength);
def stockVol = StDev(stockChange, hedgeLength);
def indexVol = StDev(indexChange, hedgeLength);
def indexSize = investment / close * hedgeRatio * stockVol / indexVol;

plot HedgeSignal = !IsNaN(entryPrice) and indexTrend < indexTrend[1];
plot HedgeSize = if HedgeSignal then Round(indexSize, 0) else Double.NaN;

HedgeSignal.SetPaintingStrategy(PaintingStrategy.BOOLEAN_POINTS);
HedgeSignal.SetDefaultColor(GetColor(4));
HedgeSize.SetPaintingStrategy(PaintingStrategy.VALUES_BELOW);
HedgeSize.SetDefaultColor(GetColor(4));
