# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2014-2023
#

input fastMomentum = yes;
input momentumLength = 10;
input dvgLength1 = 5;
input dvgLength2 = 8;
input dvgLength3 = 13;
input entryNumber = 1;
input maxDivergences = 3;
input longOnly = no;

Assert(entryNumber >= 1 and entryNumber <= 3 , "'entryNumber' must be 1, 2, or 3: " + entryNumber);
Assert(maxDivergences >= 1 and maxDivergences <= 3, "'maxDivergences' must be 1, 2, or 3: " + maxDivergences);

def momentum;
if fastMomentum {
    momentum = reference StochasticFast(KPeriod = momentumLength).FastK;
} else {
    momentum = reference StochasticFast(KPeriod = momentumLength).FastD;
}

def priceSlope1 = reference LinearRegressionSlope(close, dvgLength1);
def momentumSlope1 = reference LinearRegressionSlope(momentum, dvgLength1);
def dvgBuy1 = priceSlope1 > 0 and momentumSlope1 < 0;
def dvgSell1 = priceSlope1 < 0 and momentumSlope1 > 0;

def priceSlope2 = reference LinearRegressionSlope(close, dvgLength2);
def momentumSlope2 = reference LinearRegressionSlope(momentum, dvgLength2);
def dvgBuy2 = priceSlope2 > 0 and momentumSlope2 < 0;
def dvgSell2 = priceSlope2 < 0 and momentumSlope2 > 0;

def priceSlope3 = reference LinearRegressionSlope(close, dvgLength3);
def momentumSlope3 = reference LinearRegressionSlope(momentum, dvgLength3);
def dvgBuy3 = priceSlope3 > 0 and momentumSlope3 < 0;
def dvgSell3 = priceSlope3 < 0 and momentumSlope3 > 0;

def nBuys = dvgBuy1 + dvgBuy2 + dvgBuy3;
def nSells = dvgSell1 + dvgSell2 + dvgSell3;
def nPriceSlopeUp = (priceSlope1 >= 0) + (priceSlope2 >= 0) + (priceSlope3 >= 0);
def nPriceSlopeDown = (priceSlope1 < 0) + (priceSlope2 < 0) + (priceSlope3 < 0);
def nMomentumSlopeUp = (momentumSlope1 >= 0) + (momentumSlope2 >= 0) + (momentumSlope3 >= 0);
def nMomentumSlopeDown = (momentumSlope1 < 0) + (momentumSlope2 < 0) + (momentumSlope3 < 0);

def sameDirection = nPriceSlopeUp == maxDivergences and nMomentumSlopeUp == maxDivergences or nPriceSlopeDown == maxDivergences and nMomentumSlopeDown == maxDivergences;

AddOrder(OrderType.BUY_AUTO, nBuys >= entryNumber, tickColor = GetColor(0), arrowColor = GetColor(0), name = "ThreePeriodDivergenceLE");
AddOrder(OrderType.SELL_AUTO, !longOnly and nSells >= entryNumber, tickColor = GetColor(1), arrowColor = GetColor(1), name = "ThreePeriodDivergenceSE");
AddOrder(OrderType.BUY_TO_CLOSE, sameDirection, tickColor = GetColor(2), arrowColor = GetColor(2), name = "ThreePeriodDivergenceSX");
AddOrder(OrderType.SELL_TO_CLOSE, sameDirection, tickColor = GetColor(3), arrowColor = GetColor(3), name = "ThreePeriodDivergenceLX");
