# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2021-2023
#

input length = 30;
input emaLength = 3;
input averageLength = 30;
input rsiLength = 5;
input volumeAverageLength = 50;
input highestLength = 5;
input atrLength = 5;
input factor = 0.1;
input criticalValue = 10;
input rsiMaxOverboughtLevel = 90;
input numAtrs = 3.0;

input averageType = AverageType.SIMPLE;

def vpn = reference VPNIndicator(length = length, "ema length" = emaLength, "average length" = averageLength, factor = factor);
def vpnAvg = MovingAverage(averageType, vpn, averageLength);
def rsi = reference RSI(length = rsiLength);
def volumeAvg = Average(volume, volumeAverageLength);

AddOrder(OrderType.BUY_AUTO,
    vpn crosses above criticalValue and
    volumeAvg > volumeAvg[50] and
    rsi < rsiMaxOverboughtLevel and
    close > Average(close, averageLength),
    tickcolor = GetColor(4),
    arrowcolor = GetColor(4),
    name = "VPN_LE");
AddOrder(OrderType.SELL_TO_CLOSE,
    vpn crosses below vpnAvg and
    close < Highest(close, highestLength) - numAtrs * WildersAverage(TrueRange(high,  close,  low), atrLength),
    tickcolor = GetColor(5),
    arrowcolor = GetColor(5),
    name = "VPN_LX");
