# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2013-2023
#

input price = hlc3;
input averageLength = 8;
input volatilityLength = 13;
input deviationFactor = 3.55;
input lowBandAdjust = 0.9;

def typical = if price >= price[1] then price - low[1] else price[1] - low;
def deviation = deviationFactor * Average(typical, volatilityLength);
def devHigh = ExpAverage(deviation, averageLength);
def devLow = lowBandAdjust * devHigh;
def medianAvg = ExpAverage(price, averageLength);

plot MidLine = Average(medianAvg, averageLength);
plot UpperBand = ExpAverage(medianAvg, averageLength) + devHigh;
plot LowerBand = ExpAverage(medianAvg, averageLength) - devLow;

LowerBand.SetDefaultColor(GetColor(1));
MidLine.SetDefaultColor(GetColor(7));
UpperBand.SetDefaultColor(GetColor(0));

AddOrder(OrderType.BUY_AUTO, close > UpperBand, name = "VolatilityBandLE", tickcolor = GetColor(0), arrowcolor = GetColor(0));
AddOrder(OrderType.SELL_AUTO, close < LowerBand, name = "VolatilityBandSE", tickcolor = GetColor(1), arrowcolor = GetColor(1));
