# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2007-2023
#

declare lower;

input price = FundamentalType.CLOSE;
input length = 21;
input returnLength = 1;
input index = {default SPX, "Nasdaq Composite", NDX, Dow30, "Russell 2000"};

Assert(returnLength > 0, "'return length' must be positive: " + returnLength);

def primaryPrice = Fundamental(price);
def primary = RateOfChange(price = primaryPrice, length = returnLength);

def secondaryPrice;
switch (index) {
case SPX:
    secondaryPrice = Fundamental(price, "SPX");
case "Nasdaq Composite":
    secondaryPrice = Fundamental(price, "$COMP");
case NDX:
    secondaryPrice = Fundamental(price, "NDX");
case "Dow30":
    secondaryPrice = Fundamental(price, "$DJI");
case "Russell 2000":
    secondaryPrice = Fundamental(price, "RUT");
}

def secondary = RateOfChange(price = secondaryPrice, length = returnLength);

plot ALPHA = Average(primary, length) - Beta(length, returnLength, index) * Average(secondary, length);
ALPHA.SetDefaultColor(GetColor(9));
