# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2015-2023
#

script ToSignature {
    input signature = 0;
    input max = 0;
    plot HO = Floor(signature / Power(max, 2));
    plot HC = Floor((signature - HO * Power(max, 2)) / max);
    plot OL = signature - HO * Power(max, 2) - HC * max;
}

input segments = 5;
input length = 1;
input showBubbles = yes;
input showLabel = yes;

Assert(segments > 0, "'segments' must be positive: " + segments);
Assert(length > 0, "'length' must be positive: " + length);

def range = high - low;
def avgRange = Average(range, 6);
def rangeMultiplier = Min(1, range / avgRange);

def HO = if range == 0 then 0 else Round(rangeMultiplier * (high - open) / range * segments , 0);
def HC = if range == 0 then 0 else Round(rangeMultiplier * (high - close) / range * segments, 0);
def OL = if range == 0 then 0 else Round(rangeMultiplier * (open - low) / range * segments, 0);

def max = segments + 1;
def tripled = max * max * max;
def coded = ((HO * max) + HC) * max + OL;
def barNumber = compoundValue(1, BarNumber(), 0);
def decoded = fold i = 1 to barNumber + 1 with r while r == 0 do
    if i == barNumber
        then tripled + coded
        else if GetValue(decoded, i) % tripled == coded
            then GetValue(decoded, i) + tripled else 0;

def highestDecoded1 = HighestAll(decoded);
def signature1 = highestDecoded1 % tripled;
def count1 = Floor(highestDecoded1 / tripled);
def sumPctP1 = GetValue(sumPctP1, 1) + if coded == signature1 then close[-length] - close > 0 else 0;
def sumAvgP1 = GetValue(sumAvgP1, 1) + if coded == signature1 then close[-length] - close else 0;

def highestDecoded2 = HighestAll(if decoded % tripled == signature1 then 0 else decoded);
def signature2 = highestDecoded2 % tripled;
def count2 = Floor(highestDecoded2 / tripled);
def sumPctP2 = GetValue(sumPctP2, 1) + if coded == signature2 then close[-length] - close > 0 else 0;
def sumAvgP2 = GetValue(sumAvgP2, 1) + if coded == signature2 then close[-length] - close else 0;
def highestDecoded3 = HighestAll(if decoded % tripled == signature1 or decoded % tripled == signature2 then 0 else decoded);
def signature3 = highestDecoded3 % tripled;
def count3 = Floor(highestDecoded3 / tripled);
def sumPctP3 = GetValue(sumPctP3, 1) + if coded == signature3 then close[-length] - close > 0 else 0;
def sumAvgP3 = GetValue(sumAvgP3, 1) + if coded == signature3 then close[-length] - close else 0;

plot S1 = coded == signature1;
plot S2 = coded == signature2;
plot S3 = coded == signature3;

DefineGlobalColor("First", GetColor(1));
DefineGlobalColor("Second", GetColor(2));
DefineGlobalColor("Third", GetColor(3));

S1.AssignValueColor(GlobalColor("First"));
S2.AssignValueColor(GlobalColor("Second"));
S3.AssignValueColor(GlobalColor("Third"));
S1.SetPaintingStrategy(PaintingStrategy.BOOLEAN_POINTS);
S2.SetPaintingStrategy(PaintingStrategy.BOOLEAN_POINTS);
S3.SetPaintingStrategy(PaintingStrategy.BOOLEAN_POINTS);
S1.SetLineWeight(3);
S2.SetLineWeight(3);
S3.SetLineWeight(3);
S1.Hide();
S2.Hide();
S3.Hide();

AddChartBubble(showBubbles and (coded == signature1 or coded == signature2 or coded == signature3), high, HO + ":" + HC + ":" + OL,
if coded == signature1 then GlobalColor("First") else if coded == signature2 then GlobalColor("Second") else GlobalColor("Third"));

AddLabel(showLabel, ToSignature(signature1, max).HO + ":" + ToSignature(signature1, max).HC + ":" + ToSignature(signature1, max).OL
+ " Count: " + count1 + " Pct" + length + "P: " + Round(sumPctP1 / count1 * 100, 0) + "% Avg" + length + "P: " + Round (sumAvgP1 / count1), GlobalColor("First"));
AddLabel(showLabel, ToSignature(signature2, max).HO + ":" + ToSignature(signature2, max).HC + ":" + ToSignature(signature2, max).OL
+ " Count: " + count2 + " Pct" + length + "P: " + Round(sumPctP2 / count2 * 100, 0) + "% Avg" + length + "P: " + Round (sumAvgP2 / count2), GlobalColor("Second"));
AddLabel(showLabel, ToSignature(signature3, max).HO + ":" + ToSignature(signature3, max).HC + ":" + ToSignature(signature3, max).OL
+ " Count: " + count3 + " Pct" + length + "P: " + Round(sumPctP3 / count3 * 100, 0) + "% Avg" + length + "P: " + Round (sumAvgP3 / count3), GlobalColor("Third"));
