# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2018-2023
#

declare lower;

input length = 40;
input over_bought = 2.0;
input over_sold = -2.0;
input showBreakoutSignals = yes;

def zeros = close - close[2];
def filter = reference EhlersSuperSmootherFilter(price = zeros, "cutoff length" = 0.5 * length);
def rms = Sqrt(Average(Sqr(filter), length));
def scaledFilter = filter / rms;

plot DSO = if AbsValue(scaledFilter) < 2 then 0.5 * Log((1 + scaledFilter / 2) / (1 - scaledFilter / 2)) else scaledFilter;
plot OverBought = over_bought;
plot ZeroLine = 0;
plot OverSold = over_sold;
plot UpSignal = if DSO crosses above OverSold then OverSold else Double.NaN;
plot DownSignal = if DSO crosses below OverBought then OverBought else Double.NaN;

UpSignal.SetHiding(!showBreakoutSignals);
DownSignal.SetHiding(!showBreakoutSignals);

DSO.SetDefaultColor(GetColor(2));
OverBought.SetDefaultColor(GetColor(7));
ZeroLine.SetDefaultColor(GetColor(7));
OverSold.SetDefaultColor(GetColor(7));
UpSignal.SetDefaultColor(Color.UPTICK);
UpSignal.SetPaintingStrategy(PaintingStrategy.ARROW_UP);
DownSignal.SetDefaultColor(Color.DOWNTICK);
DownSignal.SetPaintingStrategy(PaintingStrategy.ARROW_DOWN);
