# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2012-2023
#

input startDate = 20110101;
input startTime = 930;
input length1 = 50;
input length2 = 30;
input launchPoint = {"Start of segment 1", "Start of segment 2", default "End of segment 2"};
input verticalLines = no;

assert(length1 > 0, "'length1' must be positive: " + length1);
assert(length2 > 0, "'length2' must be positive: " + length2);

def after1 = daysFromDate(startDate) > 0 or (daysFromDate(startDate) == 0 and secondsFromTime(startTime) >= 0);
def firstVisible = compoundValue(1, no, yes);
def point1 = after1 and (!after1[1] or firstVisible);
def count = TotalSum(after1) - 1;
def point2 = count == length1;

def slope = if point1 then (close[-length1] - close) / length1 else if point2 then (close[-length2] - close) / length2 else slope[1];
def line = if point1 or point2 then close else line[1] + slope[1];

def start;
switch (launchPoint) {
case "Start of segment 1":
    start = 0;
case "Start of segment 2":
    start = length1;
case "End of segment 2":
    start = length1 + length2;
}
def offset = count - start;

def EF = length1;
def DE = length2;
def ratio = EF / DE;
def CD = DE / ratio;
def BC = CD / ratio;
def AB = BC / ratio;
def FG = EF * ratio;
def GH = FG * ratio;
def HI = GH * ratio;
def IJ = HI * ratio;
def CE = Sqrt(Sqr(CD) + Sqr(DE));
def EG = CE * Sqr(ratio);
def FH = EG * ratio;

plot Erman =
    offset == Floor(GH) or
    offset == Floor(FH) or
    offset == Floor(HI) or
    offset == Floor(IJ) or
    offset == Floor(DE + EF + CD) or
    offset == Floor(GH + HI + IJ) or
    offset == Floor(CD + DE + EF + FG + GH + HI) or
    offset == Floor(EF + FG + GH) or
    offset == Floor(CD + DE + EF + FG + GH) or
    offset == Floor(GH + IJ + CD + AB + EF);
plot Coles =
    offset == Floor(FH + FG + GH) or
    offset == Floor(AB + BC + CD + DE) or
    offset == Floor(AB + BC + CD + DE + GH) or
    offset == Floor(FG + GH) or
    offset == Floor(GH + HI) or
    offset == Floor(FG + BC + CD) or
    offset == Floor(FG + BC + CD + DE) or
    offset == Floor(CD + BC) or
    offset == Floor(DE + BC) or
    offset == Floor(CD + DE + CE) or
    offset == Floor(EF + FG + EG);

plot Launch = after1 and offset == 0;
plot Segments = if after1 and count <= length1 + length2 then line else Double.NaN;

Erman.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_DOWN);
Erman.SetLineWeight(3);
Erman.SetDefaultColor(GetColor(8));
Coles.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_DOWN);
Coles.SetLineWeight(3);
Coles.SetDefaultColor(GetColor(1));
Launch.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_DOWN);
Launch.SetLineWeight(3);
Launch.SetDefaultColor(GetColor(0));
Segments.SetDefaultColor(GetColor(2));
Launch.SetLineWeight(2);
Segments.HideBubble();

DefineGlobalColor("Erman", GetColor(8));
DefineGlobalColor("Coles", GetColor(1));
AddVerticalLine(verticalLines and Erman, "", globalColor("Erman"));
AddVerticalLine(verticalLines and Coles, "", globalColor("Coles"));
