# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2013-2023
#

declare lower;

input index = {default SPX, "Nasdaq Composite", NDX, Dow30, "Russell 2000"};
input returnlength = 1;
input length = 52;
input defaultValue = 0.1;

Assert(returnlength > 0, "'return length' must be positive: " + returnlength);

def logic;
switch (index) {
case SPX:
    logic = close("SPX");
case "Nasdaq Composite":
    logic = close("$COMP");
case NDX:
    logic = close("NDX");
case "Dow30":
    logic = close("$DJI");
case "Russell 2000":
    logic = close("RUT");
}
def pctChgIndex =  if logic[returnlength] == 0 then 0 else (logic - logic[returnlength]) / logic[returnlength];
def fastVarianceIndex = WMA(Sqr(pctChgIndex), length) - Sqr(WMA(pctChgIndex, length));
def pctChg = if close[returnlength] == 0 then 0 else (close - close[returnlength]) / close[returnlength];
def fastCovariance = WMA(pctChgIndex * pctChg, length) - WMA(pctChgIndex, length) * WMA(pctChg, length);

def beta = fastCovariance / fastVarianceIndex;
plot FastBeta = if IsNaN(beta) then defaultValue else beta;

FastBeta.SetDefaultColor(GetColor(9));
