# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2019-2023
#

declare lower;

input length = 20;
input bandwidth = 0.1;

def bandpass1 = reference BandpassFilter(length = length, bandwidth = bandwidth, harmonic = 1);
def bandpass2 = reference BandpassFilter(length = length, bandwidth = bandwidth, harmonic = 2);
def bandpass3 = reference BandpassFilter(length = length, bandwidth = bandwidth, harmonic = 3);

def quadrature1 = length / (2 * Double.Pi) * (bandpass1 - bandpass1[1]);
def quadrature2 = length / (2 * Double.Pi) * (bandpass2 - bandpass2[1]);
def quadrature3 = length / (2 * Double.Pi) * (bandpass3 - bandpass3[1]);

def power1 = Sum(Sqr(bandpass1) + Sqr(quadrature1), length);
def power2 = Sum(Sqr(bandpass2) + Sqr(quadrature2), length);
def power3 = Sum(Sqr(bandpass3) + Sqr(quadrature3), length);

plot Wave = bandpass1 + Sqrt(power2 / power1) * bandpass2 + Sqrt(power3 / power1) * bandpass3;
plot ROC = length / (4 * Double.Pi) * (Wave - Wave[2]);
plot ZeroLine = 0;

Wave.SetDefaultColor(GetColor(2));
ROC.SetDefaultColor(GetColor(1));
ZeroLine.SetDefaultColor(GetColor(7));
