# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2012-2023
#

declare lower;

input temaLength = 55;
input emaLength = 60;
input candleSizeFactor = 1.1;

assert(candleSizeFactor >= 0, "'candle size factor' must not be negative: " + candleSizeFactor);

def haOpen = CompoundValue(1, (haOpen[1] + ohlc4[1]) / 2, ohlc4);
def haClose = (haOpen + Max(high, haOpen) + Min(low, haOpen) + ohlc4) / 4;
def temaHaClose = TEMA(haClose, temaLength);
def zeroLagHaClose = 2 * temaHaClose - TEMA(temaHaClose, temaLength);
def temaTypPrice = TEMA(hl2, temaLength);
def zeroLagTypPrice = 2 * temaTypPrice - TEMA(temaTypPrice, temaLength);
def shortCandle = BodyHeight() < (high - low) * candleSizeFactor;

def keepGreen = haClose >= haOpen or haClose[1] >= haOpen[1] or close >= haClose or high > high[1] or low > low[1] or zeroLagTypPrice >= zeroLagHaClose;
def keepGreenAll = keepGreen or (keepGreen[1] and (close >= open or close >= close[1]));
def holdLong = shortCandle and high >= low[1];
def utr = keepGreenAll or (keepGreenAll[1] and holdLong);

def keepRed = haClose < haOpen or haClose[1] < haOpen[1] or zeroLagTypPrice < zeroLagHaClose;
def keepRedAll = keepRed or (keepRed[1] and (close < open or close < close[1]));
def holdShort = shortCandle and low <= high[1];
def dtr = keepRedAll or (keepRedAll[1] and holdShort);

def upw = !dtr and dtr[1] and utr;
def dnw = !utr and utr[1] and dtr;
def upwSave = if upw or dnw then upw else upwSave[1];
def buy = upw or (!dnw and upwSave);
def longTermSell = close < ExpAverage(close, emaLength);
def neutral = buy or (if longTermSell then no else neutral[1]);

plot HACOLT = if buy then 100 else if neutral then 50 else 0;
HACOLT.DefineColor("Up", Color.UPTICK);
HACOLT.DefineColor("Neutral", Color.GRAY);
HACOLT.DefineColor("Down", Color.DOWNTICK);
HACOLT.AssignValueColor(if HACOLT == 100 then HACOLT.Color("Up") else if HACOLT == 50 then HACOLT.Color("Neutral") else HACOLT.Color("Down"));
