# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2014-2023
#
#wizard text: Inputs: rsi length:
#wizard input: rsiLength
#wizard text: rsi average type:
#wizard input: rsiAverageType
#wizard text: rsi oversold level:
#wizard input: rsiOversoldLevel
#wizard text: average length:
#wizard input: averageLength
#wizard text: average type:
#wizard input: averageType
#wizard text: volume limit:
#wizard input: volumeLimit
#wizard text: check earnings surprises:
#wizard input: checkEarningsSurprises
#wizard text: beta limit:
#wizard input: betaLimit

input rsiLength = 2;
input rsiAverageType = AverageType.WILDERS;
input rsiOversoldLevel = 5;
input averageLength = 200;
input averageType = AverageType.EXPONENTIAL;
input volumeLimit = 1000000;
input checkEarningsSurprises = yes;
input betaLimit = 1.0;

def slowMA = MovingAverage(averageType, close, averageLength);
def rsi = reference RSI(length = rsiLength, averageType = rsiAverageType);
def lastEarningsOffset;
def lastEarningsSurprise;
if checkEarningsSurprises {
    lastEarningsOffset = GetEventOffset(Events.EARNINGS, -1);
    lastEarningsSurprise = GetValue(GetActualEarnings(), lastEarningsOffset) > GetValue(GetEstimatedEarnings(), lastEarningsOffset);
} else {
    lastEarningsOffset = Double.NaN;
    lastEarningsSurprise = yes;
}

plot LongHaulScreen = rsi < rsiOversoldLevel and
    close > slowMA and
    Average(volume, 50) > volumeLimit and
    Beta() > betaLimit and
    if IsNaN(lastEarningsSurprise) then yes else lastEarningsSurprise;
LongHaulScreen.SetPaintingStrategy(PaintingStrategy.BOOLEAN_POINTS);
LongHaulScreen.SetLineWeight(3);
LongHaulScreen.SetDefaultColor(GetColor(1));
