# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2012-2023
#

declare lower;

input price = close;
input fastLength = 12;
input slowLength = 26;
input MACDLength = 9;
input AverageType = {SMA, default EMA};
input MACDLevel = 0.0;

def fastEMA = ExpAverage(price, fastLength);
def slowEMA = ExpAverage(price, slowLength);

plot Value;
plot Avg;
switch (AverageType) {
case SMA:
    Value = Average(price, fastLength) - Average(price, slowLength);
    Avg = Average(Value, MACDLength);
case EMA:
    Value = fastEMA - slowEMA;
    Avg = ExpAverage(Value, MACDLength);
}

plot Diff = Value - Avg;
plot Level = MACDLevel;

def PMACDeq = reference ReverseEngineeringMACD(price, fastLength, slowLength, MACDLength, AverageType, MACDLevel).PMACDeq;
def PMACDlevel = reference ReverseEngineeringMACD(price, fastLength, slowLength, MACDLength, AverageType, MACDLevel).PMACDlevel;
def PMACDsignal = reference ReverseEngineeringMACD(price, fastLength, slowLength, MACDLength, AverageType, MACDLevel).PMACDsignal;
AddLabel(yes, "PMACDeq: " + Round(PMACDeq[-1]), Value.TakeValueColor());
AddLabel(yes, "PMACDlevel: " + Round(PMACDlevel[-1]), Level.TakeValueColor());
AddLabel(yes, "PMACDsignal: " + Round(PMACDsignal[-1]), GetColor(5));

Value.SetDefaultColor(GetColor(1));
Avg.SetDefaultColor(GetColor(8));
Diff.DefineColor("Positive and Up", Color.GREEN);
Diff.DefineColor("Positive and Down", Color.DARK_GREEN);
Diff.DefineColor("Negative and Down", Color.RED);
Diff.DefineColor("Negative and Up", Color.DARK_RED);
Diff.AssignValueColor(if Diff >= 0
		then if Diff > Diff[1] then Diff.color("Positive and Up") else Diff.color("Positive and Down")
  		else if Diff < Diff[1] then Diff.color("Negative and Down") else Diff.color("Negative and Up"));
Diff.SetPaintingStrategy(PaintingStrategy.HISTOGRAM);
Diff.SetLineWeight(3);
Level.SetDefaultColor(GetColor(3));
