# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2015-2023
#

declare lower;

input length = 20;
input groupingOffset = 1;
input goal = 9.99;

Assert(groupingOffset > 0, "'grouping offset' must be positive: " + groupingOffset);

def rangeLow = close[groupingOffset] - Lowest(low, groupingOffset);
def rangeHigh = close[groupingOffset] - Highest(high, groupingOffset);

plot GoalLevel = Round(goal, 2);
plot MTR = Max(AbsValue(rangeLow), AbsValue(rangeHigh));

GoalLevel.SetDefaultColor(GetColor(7));
MTR.SetPaintingStrategy(PaintingStrategy.HISTOGRAM);
MTR.SetLineWeight(3);
MTR.AssignValueColor(if MTR >= goal then Color.GREEN else Color.RED);

def goalCount = Sum(MTR >= goal, length);
def mtrStdDev = StDev(MTR, length);
def mtrAvg = Average(MTR, length);
def oneIVSD = close * imp_volatility / Sqrt(252);

AddLabel(groupingOffset > 1, "* Special grouping is set for " + groupingOffset + " bars *", Color.LIGHT_ORANGE) ;
AddLabel(yes, "Period Length: " + length, Color.LIGHT_GREEN);
AddLabel(yes, "Goal: " + GoalLevel, Color.LIGHT_GREEN);
AddLabel(yes, "Goal Count: " + goalCount, Color.LIGHT_GREEN);
AddLabel(yes, "Percent Goal Achieved: " + AsPercent(goalCount / length), Color.LIGHT_GREEN);
AddLabel(yes, "MTR Avg: " + Round(mtrAvg, 2), Color.LIGHT_GRAY);
AddLabel(yes, "MTR Std Dev: " + Round(mtrStdDev, 2) , Color.LIGHT_GRAY);
AddLabel(GetAggregationPeriod() == AggregationPeriod.DAY, "IV Std Dev: " + Round(oneIVSD, 2), Color.LIGHT_GRAY);
AddLabel(GetAggregationPeriod() == AggregationPeriod.DAY, "Mean/IV Ratio: " + Round(mtrAvg / oneIVSD, 2), Color.LIGHT_GRAY);
