# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2017-2023
#

declare lower;

input price = close;
input priceAverageLength = 21;
input momentumLength = 22;
input momentumAverageLength = 7;
input showBreakoutSignals = yes;

Assert(momentumLength > 0, "'momentum length' must be positive: " + momentumLength);

def priceAvg = Average(price, priceAverageLength);
def momentumPercent = priceAvg / priceAvg[momentumLength] * 100;
def momentumPercentAvg = Average(momentumPercent, momentumAverageLength);

plot MomentumHistogram = momentumPercent - momentumPercentAvg;
plot ZeroLine = 0;
plot UpSignal = if MomentumHistogram crosses above ZeroLine then ZeroLine else Double.NaN;
plot DownSignal = if MomentumHistogram crosses below ZeroLine then ZeroLine else Double.NaN;

UpSignal.SetHiding(!showBreakoutSignals);
DownSignal.SetHiding(!showBreakoutSignals);

MomentumHistogram.SetDefaultColor(GetColor(5));
MomentumHistogram.SetPaintingStrategy(PaintingStrategy.HISTOGRAM);
MomentumHistogram.SetLineWeight(3);
MomentumHistogram.DefineColor("Positive and Up", Color.GREEN);
MomentumHistogram.DefineColor("Positive and Down", Color.DARK_GREEN);
MomentumHistogram.DefineColor("Negative and Down", Color.RED);
MomentumHistogram.DefineColor("Negative and Up", Color.DARK_RED);
MomentumHistogram.AssignValueColor(if MomentumHistogram >= 0 then if MomentumHistogram > MomentumHistogram[1] then MomentumHistogram.Color("Positive and Up") else MomentumHistogram.Color("Positive and Down") else if MomentumHistogram < MomentumHistogram[1] then MomentumHistogram.Color("Negative and Down") else MomentumHistogram.Color("Negative and Up"));
ZeroLine.SetDefaultColor(GetColor(7));
UpSignal.SetDefaultColor(Color.UPTICK);
UpSignal.SetPaintingStrategy(PaintingStrategy.ARROW_UP);
DownSignal.SetDefaultColor(Color.DOWNTICK);
DownSignal.SetPaintingStrategy(PaintingStrategy.ARROW_DOWN);
