# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2019-2023
#

declare lower;
declare zerobase;

input years = 4;
input highFrequency = 75;
input lowFrequency = 25;

Assert(GetAggregationPeriod() == AggregationPeriod.MONTH, "The `MonthlySeasonality` study is designed for monthly charts only");

def year = GetYear();
def month = GetMonth();
def isNewYear = year != year[1];
def yearlyAvg = if isNewYear then Average(close, 12)[-11] else yearlyAvg[1];
def monthlyReturn = (close / yearlyAvg) - 1;

plot PositiveReturnsFrequency = (fold i = 0 to years with freq do freq + GetValue(monthlyReturn > 0, i * 12, 12 * ( years - 1 ))) / years * 100;
plot HighFrequencyLevel = highFrequency;
plot LowFrequencyLevel = lowFrequency;

PositiveReturnsFrequency.SetPaintingStrategy(PaintingStrategy.HISTOGRAM);
PositiveReturnsFrequency.DefineColor("High", Color.DOWNTICK);
PositiveReturnsFrequency.DefineColor("Middle", Color.GRAY);
PositiveReturnsFrequency.DefineColor("Low", Color.UPTICK);
PositiveReturnsFrequency.AssignValueColor(
    if PositiveReturnsFrequency >= highFrequency then PositiveReturnsFrequency.Color("High")
    else if PositiveReturnsFrequency <= lowFrequency then PositiveReturnsFrequency.Color("Low")
    else PositiveReturnsFrequency.Color("Middle"));
HighFrequencyLevel.SetDefaultColor(Color.DOWNTICK);
LowFrequencyLevel.SetDefaultColor(Color.UPTICK);
