# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2011-2023
#

script getPrice {
    input price = FundamentalType.CLOSE;
    input currency = {default "EUR", "GBP", "JPY", "CAD", "CHF", "NZD", "AUD"};
    plot SecondaryPrice;
    switch (currency) {
    case "EUR":
        SecondaryPrice = fundamental(price, "/6E");
    case "GBP":
        SecondaryPrice = fundamental(price, "/6B");
    case "JPY":
        SecondaryPrice = fundamental(price, "/6J");
    case "CAD":
        SecondaryPrice = fundamental(price, "/6C");
    case "CHF":
        SecondaryPrice = fundamental(price, "/6S");
    case "NZD":
        SecondaryPrice = fundamental(price, "/6N");
    case "AUD":
        SecondaryPrice = fundamental(price, "/6A");
    }
}

declare lower;

input firstCurrency = {default "EUR", "GBP", "JPY", "CAD", "CHF", "NZD", "AUD"};
input secondCurrency =  {"EUR", "GBP", default "JPY", "CAD", "CHF", "NZD", "AUD"};
input areOneWayPairs = no;
input multiplier = 10000.0;
input upperLimit = 0.1;
input lowerLimit = -0.1;

assert(multiplier > 0, "'multiplier' must not be negative: " + multiplier);

def firstClose = getPrice(FundamentalType.CLOSE, firstCurrency);
def firstOpen = getPrice(FundamentalType.OPEN, firstCurrency);
def secondClose = getPrice(FundamentalType.CLOSE, secondCurrency);
def secondOpen = getPrice(FundamentalType.OPEN, secondCurrency);

plot Corr = (firstClose - firstOpen) + (secondClose - secondOpen) * multiplier * if areOneWayPairs then 1 else -1;
plot Upper = upperLimit;
plot Lower = lowerLimit;

Corr.SetPaintingStrategy(PaintingStrategy.HISTOGRAM);
Corr.SetLineWeight(3);
Corr.DefineColor("Positive", Color.UPTICK);
Corr.DefineColor("Negative", Color.DOWNTICK);
Corr.AssignValueColor(if Corr >= 0 then Corr.color("Positive") else Corr.color("Negative"));
Upper.SetDefaultColor(Color.GRAY);
Lower.SetDefaultColor(Color.GRAY);
