# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2017-2023
#

declare lower;

input secondarySymbol = "FXY";
input rocLength = 3;
input divergenceLength = 50;
input divergenceMomentumLength = 50;
input level_1 = 75;
input level_2 = 25;

def roc1 = reference RateOfChange(price = close, length = rocLength);
def roc2 = reference RateOfChange(price = close(secondarySymbol), length = rocLength);
def corr = Correlation(roc1, roc2, divergenceLength);
def b = corr * StDev(roc1, divergenceLength) / (StDev(roc2, divergenceLength) + 0.001);
def a = Average(roc1, divergenceLength) - b * Average(roc2, divergenceLength);
def pred2 = b * roc2 + a;
def div2 = pred2 - roc1;

plot RegressionDivergence = (Average(div2 - Lowest(div2, divergenceMomentumLength), 2) * 100) / (Average(Highest(div2, divergenceMomentumLength) - Lowest(div2, divergenceMomentumLength), 2) + 0.01);
plot Level1 = level_1;
plot Level2 = level_2;

RegressionDivergence.SetDefaultColor(GetColor(5));
Level1.SetDefaultColor(GetColor(7));
Level2.SetDefaultColor(GetColor(7));
