# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2012-2023
#

input price = close;
input keltnerLength = 13;
input volumeFastLength = 1;
input volumeSlowLength = 20;
input ADXLength = 10;
input SMALength = 8;
input volumeOscThreshold = 0.5;
input paintBars = yes;

def keltnerSMA = Average(hlc3, keltnerLength);
def avgRange = Average(high - low, keltnerLength);
def volumeOsc = reference VolumeOsc("fast length" = volumeFastLength, "slow length" = volumeSlowLength, "diff type" = "percent");
def ADX = reference ADX(ADXLength, AverageType.WILDERS);
def SMA = Average(price, SMALength);

plot KeltnerHigh = keltnerSMA + avgRange;
plot KeltnerMid = keltnerSMA;
plot KeltnerLow = keltnerSMA - avgRange;
plot VolumeSpike = volumeOsc > volumeOscThreshold;

KeltnerHigh.SetDefaultColor(GetColor(4));
KeltnerMid.SetDefaultColor(GetColor(4));
KeltnerMid.SetStyle(Curve.LONG_DASH);
KeltnerLow.SetDefaultColor(GetColor(4));
VolumeSpike.SetDefaultColor(GetColor(1));
VolumeSpike.SetLineWeight(3);
VolumeSpike.SetPaintingStrategy(PaintingStrategy.BOOLEAN_POINTS);

DefineGlobalColor("Up", Color.UPTICK);
DefineGlobalColor("Neutral", Color.GRAY);
DefineGlobalColor("Down", Color.DOWNTICK);
AssignPriceColor( if !paintBars
    then Color.CURRENT
    else if ADX > ADX[1] and price > SMA
        then globalColor("Up")
        else if ADX > ADX[1] and price < SMA
            then globalColor("Down")
            else globalColor("Neutral"));
