# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2018-2023
#

declare lower;

input vfiLength = 130;
input averageLength = 100;
input trendQualityLength = 63;
input maxStiffness = 7;
input marketIndex = "SPY";
input weightForMoneyFlow = 1.0;
input weightForTradingAboveAverage = 1.0;
input weightForUptrend = 1.0;
input weightForTrendQuality = 1.0;
input weightForMarketDirection = 2.0;
input showLabel = yes;

def vfi = reference VolumeFlowIndicator(length = vfiLength, "max volume cut off" = 2.5);
def sma = Average(close, averageLength);
def ema = ExpAverage(close(marketIndex), averageLength);
def stiffness = Sum(close < sma, trendQualityLength);

plot Score;
plot MoneyFlow = vfi > 0;
plot TradingAboveAverage = close > sma;
plot Uptrend = sma > sma[4];
plot TrendQuality = stiffness <= maxStiffness;
plot MarketDirection = ema >= ema[2];

Score = weightForMoneyFlow * MoneyFlow + weightForTradingAboveAverage * TradingAboveAverage + weightForUptrend * Uptrend + weightForTrendQuality * TrendQuality + weightForMarketDirection * MarketDirection;
Score.SetDefaultColor(GetColor(1));
MoneyFlow.SetDefaultColor(GetColor(2));
MoneyFlow.Hide();
TradingAboveAverage.SetDefaultColor(GetColor(3));
TradingAboveAverage.Hide();
Uptrend.SetDefaultColor(GetColor(4));
Uptrend.Hide();
TrendQuality.SetDefaultColor(GetColor(5));
TrendQuality.Hide();
MarketDirection.SetDefaultColor(GetColor(6));
MarketDirection.Hide();

AddLabel(showLabel and MoneyFlow, "Money flow", MoneyFlow.TakeValueColor());
AddLabel(showLabel and TradingAboveAverage, "Trading above average", TradingAboveAverage.TakeValueColor());
AddLabel(showLabel and Uptrend, "Uptrend", Uptrend.TakeValueColor());
AddLabel(showLabel and TrendQuality, "Trend quality", TrendQuality.TakeValueColor());
AddLabel(showLabel and MarketDirection, "Market direction", MarketDirection.TakeValueColor());
