# @new
# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2016-2023
#

input macdFastLength = 12;
input macdSlowLength = 26;
input weightedAverageLength = 34;
input exponentialAverageLength = 55;
input paintBars = yes;

def macd = reference MACD("fast length" = macdFastLength, "slow length" = macdSlowLength, "average type" = AverageType.EXPONENTIAL).Value;

plot WeightedAverage = WMA(close, weightedAverageLength);
plot ExponentialAverage = ExpAverage(close, exponentialAverageLength);

plot MACDAboveZeroCrossover = macd crosses above 0;
plot MACDBelowZeroCrossover = macd crosses below 0;

plot UpperWarningSymbol = close < WeightedAverage and high >= ExponentialAverage;
plot LowerWarningSymbol = ExponentialAverage > WeightedAverage and close > WeightedAverage;

WeightedAverage.SetDefaultColor(GetColor(3));
ExponentialAverage.SetDefaultColor(GetColor(5));
MACDAboveZeroCrossover.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_UP);
MACDAboveZeroCrossover.SetDefaultColor(GetColor(1));
MACDAboveZeroCrossover.Hide();
MACDBelowZeroCrossover.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_DOWN);
MACDBelowZeroCrossover.SetDefaultColor(GetColor(2));
MACDBelowZeroCrossover.Hide();
UpperWarningSymbol.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_DOWN);
UpperWarningSymbol.SetDefaultColor(GetColor(0));
LowerWarningSymbol.SetPaintingStrategy(PaintingStrategy.BOOLEAN_ARROW_UP);
LowerWarningSymbol.SetDefaultColor(GetColor(3));

DefineGlobalColor("Positive", GetColor(1));
DefineGlobalColor("Negative", GetColor(2));
AssignPriceColor(if !paintBars
    then Color.CURRENT
    else if macd >= 0
        then GlobalColor("Positive")
        else GlobalColor("Negative"));
