# @reference
#
# TD Ameritrade IP Company, Inc. (c) 2009-2023
#

declare lower;

input price = close;
input reversalAmount = 8.0;

assert(reversalAmount > 0, "'reversal amount' should be positive: " + reversalAmount);

def state = {default init, undefined, uptrend, downtrend};
def trendPrice;

switch (state[1]) {
case init:
    trendPrice = price;
    state = state.undefined;
case undefined:
    if (price <= trendPrice[1] - trendPrice[1] * reversalAmount / 100) {
        state = state.downtrend;
        trendPrice = price;
    } else if (price >= trendPrice[1] + trendPrice[1] * reversalAmount / 100) {
        state = state.uptrend;
        trendPrice = price;
    } else {
        state = state.undefined;
        trendPrice = trendPrice[1];
    }
case uptrend:
    if (price <= trendPrice[1] - trendPrice[1] * reversalAmount / 100) {
        state = state.downtrend;
        trendPrice = price;
    } else {
        state = state.uptrend;
        trendPrice = Max(price, trendPrice[1]);
    }
case downtrend:
    if (price >= trendPrice[1] + trendPrice[1] * reversalAmount / 100) {
        state = state.uptrend;
        trendPrice = price;
    } else {
        state = state.downtrend;
        trendPrice = Min(price , trendPrice[1]);
    }
}

plot "ZZT%" = if state == state.uptrend and !IsNan(close) then 1 else if state == state.downtrend and !IsNan(close) then -1 else Double.NaN;

"ZZT%".SetDefaultColor(GetColor(1));
